心灵奇旅 (豆瓣)
Description: 心灵奇旅电影简介和剧情介绍,心灵奇旅影评、图片、预告片、影讯、论坛、在线购票
Keywords: 心灵奇旅,Soul,心灵奇旅影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.208豆瓣电影Top250

# 心灵奇旅 Soul (2020)

导演: 彼特·道格特 / 凯普·鲍尔斯
编剧: 彼特·道格特 / 麦克·琼斯 / 凯普·鲍尔斯
主演: 杰米·福克斯 / 蒂娜·菲 / 菲利西亚·拉斯海德 / 阿米尔-卡利布·汤普森 / 戴维德·迪格斯 / 格拉汉姆·诺顿 / 瑞切尔·豪斯 / 艾莉丝·布拉加 / 理查德·艾欧阿德 / 唐尼尔·罗林斯 / 安吉拉·贝塞特 / 马戈·霍尔 / 罗德莎·琼斯 / 韦斯·斯塔迪 / 沙基纳·贾弗里 / 福琼·费姆斯特 / 卡鲁姆·格兰特 / 泽诺比娅·谢罗夫 / 朱恩·斯奎布 / 凯茜·卡瓦蒂妮 / 罗纳尔多·德尔·卡门 / 埃利萨皮·艾萨克 / 杰森·佩斯 / 科拉·尚波米耶
类型: 动画 / 音乐 / 奇幻
官方网站: https://movies.disney.com/soul
制片国家/地区: 美国
语言: 英语
上映日期: 2020-12-25(中国大陆/美国网络) / 2020-10-11(伦敦电影节)
片长: 101分钟
又名: 灵魂奇遇记(港) / 灵魂急转弯(台) / 灵魂 / 心灵
IMDb: tt2948372
豆瓣评分
引用
8.7
912207人评价
5星
48.6%
4星
38.5%
3星
11.9%
2星
0.8%
1星
0.2%
好于 97% 动画片
好于 97% 奇幻片
想看 看过
评价:
推荐

## 心灵奇旅的剧情简介 · · · · · ·

究竟是什么塑造了真正的你？电影将聚焦乔伊·高纳（杰米·福克斯配音）。这位中学音乐老师获得了梦寐以求的机会——在纽约最好的爵士俱乐部演奏。但一个小失误把他从纽约的街道带到了一个奇幻的地方“生之来处”（the Great Before）。在那里，灵魂们获得培训，在前往地球之前将获得他们的个性特点和兴趣。决心要回到地球生活的乔伊认识了一个早熟的灵魂“二十二”（蒂娜·菲 配音），二十二一直找不到自己对于人类生活的兴趣。随着乔伊不断试图向二十二展示生命的精彩之处，他也将领悟一些人生终极问题的答案。

## 心灵奇旅的演职员 · · · · · · ( 全部 34 )

- 彼特·道格特 导演
- 凯普·鲍尔斯 联合执导
- 杰米·福克斯 配 Joe Gardner
- 蒂娜·菲 配 22
- 菲利西亚·拉斯海德 配 Libba Gardner
- 阿米尔-卡利布·汤普森 配 Curly

## 心灵奇旅的视频和图片 · · · · · · ( 预告片8 | 视频评论2 · 添加 | 图片1409 · 添加 )

## 心灵奇旅的获奖情况 · · · · · · ( 全部 )

- 第73届戛纳电影节
- 动画片(提名)

- 第78届金球奖
- 电影类 最佳动画长片

- 第74届英国电影学院奖
- 电影奖 最佳动画片
- 凯普·鲍尔斯 / 彼特·道格特

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  哈尔的移动城堡

  玩具总动员

  幽灵公主

  怪兽电力公司

  东京教父

  红辣椒

  魔女宅急便

  美食总动员

  青春变形记

我要写短评

## 心灵奇旅的短评 · · · · · · ( 全部 342636 条 )

热门 / 最新 / 好友

### 26029 有用 礼拜六的两脚兽 看过 2020-12-16 19:00:15

未必有所成才算活着，梦想也不是什么了不起的东西，只喜欢看天、走路、吃披萨的人生也很好。（皮克斯送给社畜社恐的一记摸头

### 12074 有用 Woody 看过 2020-12-25 09:35:39

一部极有可能拿到奥斯卡最佳动画长片/最佳原创配乐的电影； 一部迪士尼皮克斯近乎满分的作品； 一个出品23部长篇动画电影，拿下10个奥斯卡奖杯的工作室； 排片2%

### 20560 有用 西楼尘 看过 2020-12-26 10:36:47

理发师用剃刀也能救人危难，造型师用针线也会缝补梦想。枝头掉落的树叶，街头鼓起的排风，地铁里忙碌人群中的歌声，角落里饥肠辘辘时的披萨，当你爱上生活的一刻，就找到了激活生命的火花。原来每天有那么多灵魂经历个体的锤炼，性格的塑造，奋力冲向地球。也会有无数灵魂被生活压垮，迷失进漠漠荒野。

### 3525 有用 朝阳区陆依萍 看过 2020-12-14 16:41:50

的确在今年看，具有抚慰人心的力量，但也就抚慰了不到3分钟吧～

### 7634 有用 懒懒牛 看过 2020-12-16 15:58:03

你以为所有的故事都被讲完了，皮克斯给你讲一个所有元素都见过但前所未有的故事。终于梦想和目标都不再重要，feel it

> 更多短评 342636条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 心灵奇旅的影评 · · · · · · ( 全部 5889 条 )

热门 / 最新 / 好友
mumudancing 2020-12-26 13:39:11

## 看到荒漠，也看到微光。

这篇影评可能有剧透

如果你的2020年和我一样糟糕，年末实在没有什么值得总结只能勉强交出一份“我还活着”的答卷，那么当你看完《心灵奇旅》这部动画片时，也许会在世界某个角落和我一起击掌——是的，一事无成也没关系，至少这个故事给了我们慰藉。 皮克斯用第23部动画长片证明它在创新路上已走得... (展开)
11816 67 522回应 收起
林探惜 2020-12-26 13:15:53

## 可是那然后呢

在我的人生里，有过一场重大的幻灭。 那是在我即将满十八岁的夏天，我站在我小学后操场的主席台中央，伸手抓着被太阳晒得发热的旗杆，闭上眼睛再睁开，眼前的一切依旧空荡安静。 没有人知道那一刻对我来说意义有多重大。 由于我爸的工作，我从小就一直跟着父母辗转于不同的城市... (展开)
5205 40 254回应 收起
一岚写故事 2020-12-26 21:41:00

## 被误读的“活在当下”

创意还行，故事略硬，不够取信于人，至少没能取信于我。有种为了讲这么一个活在当下的主题，硬设计了这么一个故事的感觉。 不知有没有人有同感，全片整体都跟寻梦的发展路线太像，但后半部分却没有推上去，人物转变生硬，虎头蛇尾。以致于看完我莫名产生一种想模仿寻梦却没仿成... (展开)
2386 373 878回应 收起
问宝侠 2020-09-02 07:45:49

## 电影还没上映评论区就有人拿zzzq来兴风作浪了，那就对线吧

（本文皆为跟电影无关的题外话，只是希望大家在点进评论区后不被另一长评毁掉好心情而写，写完也觉得有点不至于，但由于我真的很爱皮克斯也爱道导也爱诺兰，忍不住还是想回嘴。也希望在影片上映后，观众都能用心体会主创真正想向大家传达的内容。） 就很离谱。 先不说本片讲的... (展开)
862 63 270回应 收起
柴斯卡 2021-01-01 08:57:29

## 为什么逻辑混乱的美式鸡汤会抬高公共沟通成本？

先上结论：皮克斯新片《soul》，和之前的作品《飞屋环游记》、《寻梦环游记》一样，是一部逻辑混乱、乃至伪善的作品，其中笑点涉及到了职场霸凌（这个格调并不比春晚上的小品高级），剧情主线甚至在讲走后门。它当然有很多优点，但优点都是技术层面的，有非常感人的亲情片段、... (展开)
782 374 502回应 收起
喜儿喂鸭正经地 2020-12-28 22:16:24

## 看皮克斯的人长大了

《怪兽电力公司》是我小时候记忆里最早看过，并且印象最深的皮克斯动画。直到今天，我依然记得在小学的电脑机房里，两个同学分享一台电脑看电影的场景。《怪兽电力公司》时间不长，一个半小时的电影时间被分配成了三四节电脑课才能完整地看完。每节电脑课上课铃还没响，所有同... (展开)
491 7 39回应 收起
捧与挖 2020-12-25 21:43:25

## 整部电影太高级了！从内而外，视听嗅味触通五感的高级！皮克斯，永远的神！

本来打算过两天去看的，但是今天下午一开分，芜湖9.2！圣诞夜给我冲！ 整个电影太高级了！从内而外，视听嗅味触通五感的高级！ 主题上，它探讨了一个终极的哲学问题：“人究竟为什么活着？”男主是一个不得志的jazz钢琴师，他终于得到梦寐以求的演出机会，结果走路太开心，死了... (展开)
548 35 76回应 收起
欢乐分裂 2020-12-25 10:31:12

## 灵魂不会击垮你 生活也不会

若论一部适合今年收尾的影片，我会毫不犹豫地推荐皮克斯2020年力作《心灵奇旅》，疫情尚且笼罩的当下，全球电影市场的式微肉眼可见，而这部好笑又好哭的治愈系作品无疑是令人瞩目的。从整体观感来讲，可以简单粗暴地对标皮克斯以往口碑作品——《头脑特工队》和《寻梦环游记》... (展开)
565 14 53回应 收起
朝暮雪 2020-12-29 22:44:30

## 追求梦想是最不重要的，看天空、走路、吃披萨才是正事！

这篇影评可能有剧透

[视频] 《心灵奇旅》豆瓣9.1分，是今年评分最高的电影。 皮克斯不用多说了，从1995年拍摄《玩具总动员》开始，至今已经拿了10次奥斯卡最佳动画长片，《心灵奇旅》多半也是明年奥斯卡最佳动画长片了。 可惜《心灵奇旅》运气不好，竟然和郭敬明的电影同一天上映，上映当天排片被... (展开)
641 17 42回应 收起
菠菜 2021-01-04 17:16:59

## 醋栗与……活在当下

看完这电影，脑海里盘旋着……契科夫的短篇小说醋栗。 那个故事，说的是一对兄弟，其中的弟弟一生的梦想就是有一个小小的庄园，雇几个仆人，然后可以在庄园里种上自家的醋栗吃。他的哥哥对他的梦想不以为然，但弟弟的确就在为这个梦想而努力，省吃俭用，不断攒钱，还娶了年老难... (展开)
164 4 32回应 收起

> 更多影评 5889篇

添加新讨论

## 讨论区 · · · · · ·

这是一部新纪元运动软邪教电影，青少年谨慎接受导... | 来自年轻人不要信邪~ | 133 回应 | 2022-11-22 17:59:19
22号是落在中国或者印度了吗？ | 来自士官甲 | 44 回应 | 2022-11-22 17:53:29
五星好评，差评的人们可以来看看 | 来自打电动的纳兰迦 | 133 回应 | 2022-11-20 07:49:06
评论区这一片吐槽真的展示了我国民众被成功主义毒... | 来自之夏图谱 | 28 回应 | 2022-11-18 17:18:13
22的火花到底是什么？ | 来自何一凡在地球 | 155 回应 | 2022-11-13 22:04:01

> 去这部影片的讨论区（全部1721条）

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 单片付费
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 评价人数超过十万的电影 (依然饭特稀)
- 陪我孤独终老的电影清单【灵魂篇】 (默)
- 豆瓣上评分人数超过5万评分高于7分的电影 (已注销)

## 谁在看这部电影 · · · · · ·

- Cloris雷菁
  刚刚 看过
- ...
  3分钟前 看过
- 水裹魚
  5分钟前 看过

1130613人看过 / 258843人想看

订阅心灵奇旅的评论:
feed: rss 2.0